<?php
/**
 * An interface for manageable accounts (logged-in users and guests likewise)
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2014 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface ManageableAccount extends FrameworkInterface {
	/**
	 * Determines whether the username exists or not
	 *
	 * @return	$exists		Whether the username exists
	 */
	function ifUsernameExists ();

	/**
	 * Determines whether the email exists or not
	 *
	 * @return	$exists		Whether the email exists
	 */
	function ifEmailAddressExists ();

	/**
	 * Checks if supplied password hash in request matches with stored in
	 * database.
	 *
	 * @param	$requestInstance	A requestable class instance
	 * @return	$matches			Whether the supplied password hash matches
	 */
	function ifPasswordHashMatches (Requestable $requestInstance);
}

// [EOF]
?>
