<?php
/**
 * The application selector main include file
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2014 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @deprecated
 * @todo		Minimize these includes
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Try to load these includes in the given order
$configAppIncludes = array(
	'class_' . FrameworkConfiguration::getSelfInstance()->getConfigEntry('app_helper_class'), // The ApplicationHelper class
	'debug',		// Some debugging stuff
	'exceptions',	// The application's own exception handler
	'loader',		// The application's class loader
	'config',		// The application's own configuration
	'config-local',	// Local configuration file (optional)
	'data',			// Application data
	'init',			// The application initializer
	'starter',		// The application starter (calls entryPoint(), etc.)
);

// Cache base path/file here
$basePathFile = FrameworkConfiguration::getSelfInstance()->getConfigEntry('application_path') . FrameworkConfiguration::getSelfInstance()->getConfigEntry('app_name');

// Is the directory there?
if (!is_dir($basePathFile)) {
	// Not found.
	trigger_error('Application ' . FrameworkConfiguration::getSelfInstance()->getConfigEntry('app_name') . ' not found.');
	exit;
} // END - if

// Load them all (try only)
foreach ($configAppIncludes as $appInc) {
	// Skip starter in test mode
	if (($appInc == 'starter') && (defined('TEST'))) {
		// Skip it here
		continue;
	} // END - if

	// Generate a FQFN for the helper class
	$appFqFn = $basePathFile . '/' . $appInc . '.php';

	// Does the include file exists?
	if ((file_exists($appFqFn)) && (is_file($appFqFn)) && (is_readable($appFqFn))) {
		// Load it
		//* DEBUG: */ print basename(__FILE__)."[".__LINE__."]: Loading ".basename($appFqFn)." - START\n";
		require($appFqFn);
		//* DEBUG: */ print basename(__FILE__)."[".__LINE__."]: Loading ".basename($appFqFn)." - END\n";
	} elseif (FrameworkConfiguration::getSelfInstance()->getConfigEntry('verbose_level') > 0) {
		// File is missing
		trigger_error(sprintf('Cannot load application script %s.php! File is missing or read-protected.',
			$appInc
		));
		exit;
	}
}

// Remove variables from namespace, which we don't need
unset($appInc);
unset($configAppIncludes);
unset($appFqFn);
unset($basePathFile);

// [EOF]
?>
